package com.huiju.estateagents.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.sample.entity.TaH5Demand;
import com.huiju.estateagents.sample.service.ITaH5DemandService;
import com.huiju.estateagents.service.ITaOrgService;
import org.apache.poi.ss.formula.functions.T;
import org.omg.CORBA.INTERNAL;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;


/**
 * <p>
    * 需求单表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/api")
public class TaH5DemandController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaH5DemandController.class);

    @Autowired
    public ITaH5DemandService iTaH5DemandService;

    @Autowired
    private ITaOrgService iTaOrgService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taH5Demand",method= RequestMethod.GET)
    public ResponseBean taH5DemandList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @RequestParam(value ="sampleName", required = false) String sampleName,
                                       @RequestParam(value ="orderer", required = false) String orderer,
                                       @RequestParam(value ="phone", required = false) String phone,
                                       @RequestParam(value ="sampleId", required = false) Integer sampleId,
                                       @RequestParam(value ="startCreateDate", required = false) String startCreateDate,
                                       @RequestParam(value ="endCreateDate", required = false) String endCreateDate,
                                       @RequestParam(value ="demandStatus", required = false) String demandStatus,
                                       HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaH5Demand> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaH5Demand> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", getOrgId(request));
            queryWrapper.eq(sampleId != null,"sample_id", sampleId);
            queryWrapper.ne("demand_status", CommConstant.STATUS_DELETE);
            queryWrapper.like(!StringUtils.isEmpty(sampleName),"sample_name", sampleName);
            queryWrapper.like(!StringUtils.isEmpty(orderer),"orderer", orderer);
            queryWrapper.like(!StringUtils.isEmpty(phone),"phone", phone);
            queryWrapper.eq(!StringUtils.isEmpty(demandStatus),"demand_status", demandStatus);
            queryWrapper.gt(!StringUtils.isEmpty(startCreateDate),"create_date", startCreateDate);
            queryWrapper.lt(!StringUtils.isEmpty(endCreateDate),"create_date", endCreateDate);
            queryWrapper.orderByDesc("create_date");

            IPage<TaH5Demand> result = iTaH5DemandService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taH5Demand 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taH5Demand",method= RequestMethod.POST)
    public ResponseBean taH5DemandAdd(@RequestBody TaH5Demand taH5Demand, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taH5Demand.setOrgId(getOrgId(request));
            taH5Demand.setOrgName(iTaOrgService.getById(getOrgId(request)).getName());
            taH5Demand.setDemandStatus(CommConstant.STATUS_NORMAL);
            taH5Demand.setCreateDate(LocalDateTime.now());
            taH5Demand.setUpdateDate(LocalDateTime.now());
            if (iTaH5DemandService.save(taH5Demand)){
                responseBean.addSuccess(taH5Demand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taH5Demand/{id}", method= RequestMethod.DELETE)
    public ResponseBean taH5DemandDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaH5DemandService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id批量删除对象
     */
    @ResponseBody
    @RequestMapping(value="/admin/batchDelTaH5Demands", method= RequestMethod.PUT)
    public ResponseBean taH5DemandBatchDelete(@RequestBody TaH5Demand taH5Demand){
        ResponseBean responseBean = new ResponseBean();
        List<Integer> demandIds = new ArrayList<>();
        try {
            for (TaH5Demand info : taH5Demand.getTaH5Demands()){
                demandIds.add(info.getDemandId());
            }
            TaH5Demand h5Demand = new TaH5Demand();
            h5Demand.setDemandStatus(CommConstant.STATUS_DELETE);
            QueryWrapper<TaH5Demand> taH5DemandQueryWrapper = new QueryWrapper<>();
            taH5DemandQueryWrapper.in("demand_id", demandIds);
            iTaH5DemandService.update(h5Demand, taH5DemandQueryWrapper);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taH5Demand 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taH5Demand/{id}",method= RequestMethod.PUT)
    public ResponseBean taH5DemandUpdate(@PathVariable Integer id,
                                        @RequestBody TaH5Demand taH5Demand){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (StringUtils.isEmpty(taH5Demand.getDemandContent())){
                responseBean.addError("请填写需求内容");
                return responseBean;
            }
            taH5Demand.setDemandId(id);
            if (iTaH5DemandService.updateById(taH5Demand)){
                responseBean.addSuccess(taH5Demand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taH5Demand/{id}",method= RequestMethod.GET)
    public ResponseBean taH5DemandGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaH5DemandService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5DemandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
