package com.huiju.estateagents.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.sample.entity.TaH5Sample;
import com.huiju.estateagents.sample.service.ITaH5SampleService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 样例表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/api")
public class TaH5SampleController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaH5SampleController.class);

    @Autowired
    public ITaH5SampleService iTaH5SampleService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taH5Sample",method= RequestMethod.GET)
    public ResponseBean taH5SampleList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @RequestParam(value ="sampleName", required = false) String sampleName,
                                       @RequestParam(value ="tag", required = false) String tag){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaH5Sample> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaH5Sample> queryWrapper = new QueryWrapper<>();
            queryWrapper.like(!StringUtils.isEmpty(sampleName), "sample_name", sampleName);
            queryWrapper.like(!StringUtils.isEmpty(tag), "tag", tag);
            queryWrapper.orderByDesc("order_no");
            queryWrapper.orderByDesc("create_date");

            IPage<TaH5Sample> result = iTaH5SampleService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taH5Sample 实体对象
     * @return
     */
    @RequestMapping(value="/taH5Sample",method= RequestMethod.POST)
    public ResponseBean taH5SampleAdd(@RequestBody TaH5Sample taH5Sample){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5SampleService.save(taH5Sample)){
                responseBean.addSuccess(taH5Sample);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taH5Sample/{id}", method= RequestMethod.DELETE)
    public ResponseBean taH5SampleDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaH5SampleService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taH5Sample 实体对象
     * @return
     */
    @RequestMapping(value="/taH5Sample/{id}",method= RequestMethod.PUT)
    public ResponseBean taH5SampleUpdate(@PathVariable Integer id,
                                        @RequestBody TaH5Sample taH5Sample){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5SampleService.updateById(taH5Sample)){
                responseBean.addSuccess(taH5Sample);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taH5Sample/{id}",method= RequestMethod.GET)
    public ResponseBean taH5SampleGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaH5SampleService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
