package com.huiju.estateagents.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.sample.entity.TaNotice;
import com.huiju.estateagents.sample.service.ITaNoticeService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 开屏通知  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/")
public class TaNoticeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNoticeController.class);

    @Autowired
    public ITaNoticeService iTaNoticeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taNotice",method= RequestMethod.GET)
    public ResponseBean taNoticeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaNotice> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaNotice> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaNotice> result = iTaNoticeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNoticeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taNotice 实体对象
     * @return
     */
    @RequestMapping(value="/taNotice",method= RequestMethod.POST)
    public ResponseBean taNoticeAdd(@RequestBody TaNotice taNotice){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaNoticeService.save(taNotice)){
                responseBean.addSuccess(taNotice);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNoticeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taNotice/{id}", method= RequestMethod.DELETE)
    public ResponseBean taNoticeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaNoticeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNoticeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNotice 实体对象
     * @return
     */
    @RequestMapping(value="/taNotice/{id}",method= RequestMethod.PUT)
    public ResponseBean taNoticeUpdate(@PathVariable Integer id,
                                        @RequestBody TaNotice taNotice){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaNoticeService.updateById(taNotice)){
                responseBean.addSuccess(taNotice);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNoticeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taNotice/{id}",method= RequestMethod.GET)
    public ResponseBean taNoticeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaNoticeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taNoticeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
